@@ -7,11 +7,11 @@
 ## http://search.cpan.org/dist/Devel-NYTProf/
 ##
 ###########################################################
-## $Id: NYTProf.pm 1404 2010-11-30 22:13:02Z tim.bunce@gmail.com $
+## $Id: NYTProf.pm 1423 2012-08-10 11:27:46Z tim.bunce@gmail.com $
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '4.06';
+our $VERSION = '4.07'; # also change in Devel::NYTProf::Core
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -248,7 +248,8 @@ ranges of all the subroutines.
 NYTProf can profile applications that fork, and does so with no loss of
 performance.
 NYTProf detects the fork and starts writing a new profile file with the pid
-appended to the filename.
+appended to the filename. Since L<nytprofhtml> only works with a single profile
+file you may want to merge multiple files using L<nytprofmerge>.
 
 =head2 Fast Profiling
 
@@ -1108,7 +1109,7 @@ file as a stream of chunks of data.
 
 =head1 TROUBLESHOOTING
 
-=head2 "Profile data incomplete, ..."
+=head2 "Profile data incomplete, ..." or "File format error: ..."
 
 This error message means the file doesn't contain all the expected data.
 That may be because it was truncated (perhaps the filesystem was full) or,
@@ -1126,13 +1127,59 @@ If the sudden death was due to a signal then L</sigexit=1> may help.
 If the sudden death was due to calling C<POSIX::_exit($status)> then you'll
 need to call L</finish_profile> before calling C<POSIX::_exit>.
 
-=head2 Some files don't have profile information
+You'll also get this error if the code trying to read the profile is itself
+being profiled. That's most likely to happen if you enable profiling via the
+C<PERL5OPT> environment variable and have forgotten to unset it.
 
-This is usually due to NYTProf being loaded after the other files, for example
+=head2 Some source files don't have profile information
+
+This is usually due to NYTProf being initialized after some perl files have
+already been compiled.
 
 If you can't alter the command line to add "C<-d:NYTProf>" you could try using
 the C<PERL5OPT> environment variable. See L</PROFILING>.
 
+You could also try using the L</use_db_sub=1> option.
+
+=head2 Eval ... has unknown invoking fid
+
+When using the statement profiler you may see a warning message like this:
+
+  Eval '(eval 2)' (fid 9, flags:viastmt,savesrc) has unknown invoking fid 10
+ 
+Notice that the eval file id (fid 9 in this case) is lower than the file id
+that invoked the eval (fid 10 in this case). This is a known problem caused by
+the way perl works and how the profiler assigns and outputs the file ids.
+The invoking fid is known but gets assigned a fid and output after the fid for
+the eval, and that causes the warning when the file is read.
+
+=head2 Warning: %d subroutine calls had negative time
+
+There are two likely causes for this: clock instability, or accumulated timing
+errors.
+
+Clock instability, if present on your system, is most likely to be noticable on
+very small/fast subroutines that are called very few times.
+
+Accumulated timing errors can arise because the subroutine profiler uses
+floating point values (NVs) to store the times.  They are most likely to be
+noticed on subroutines that are called a few times but which make a large
+number of calls to very fast subroutines (such as opcodes). In this case the
+accumulated time apparently spent making those calls can be greater than the
+time spent in the calling subroutine.
+
+If you rerun nytprofhtml (etc.) with the L</trace=N> option set >0 you'll see
+trace messages like  "%s call has negative time: incl %fs, excl %fs" for each
+affected subroutine.
+
+Try profiling with the L</slowops=N> option set to 0 to disable the profiling
+of opcodes. Since opcodes often execute in a few microseconds they are a common
+cause of this warning.
+
+You could also try recompiling perl to use 'long doubles' for the NV floating
+point type (use Configure -Duselongdouble). If you try this please let me know.
+I'd also happily take a patch to use long doubles, if available, by default.
+
 =head1 AUTHORS AND CONTRIBUTORS
 
 B<Tim Bunce> (L<http://www.tim.bunce.name> and L<http://blog.timbunce.org>)
